import { Request, Response } from 'express';
import { prisma, __path, log } from '../../index.js';

async function get(req: Request, res: Response) {
	// If no page is provided redirect to first
	if (req.query.page === undefined) {
		res.redirect('?page=1');
		return;
	}

	let page = parseInt(req.query.page.toString());
	const itemCount = await prisma.item.count({}); // Count all items in the DB

	const takeSize = 25; // Amount of times per page
	const pageSize = Math.ceil(itemCount / takeSize); // Amount of pages, always round up

	// If page is less then 1 or more then the max page size redirect to first or last page. If itemCount is 0 do not redirect.
	if (page < 1) {
		res.redirect('?page=1');
		return;
	} else if (page > pageSize && itemCount !== 0) {
		res.redirect('?page=' + pageSize);
		return;
	}
	prisma.item
		.findMany({ skip: (page - 1) * takeSize, take: takeSize }) // Skip the amount of items per page times the page number minus 1; skip has to be (page-1)*takeSize because skip is 0 indexed
		.then((items) => {
			prisma.storageLocation.findMany({}).then((locations) => {
				prisma.itemCategory.findMany({}).then((categories) => {
					res.render(__path + '/src/frontend/items.eta.html', { items: items, currentPage: page, maxPages: pageSize, storeLocs: locations, categories: categories });
				});
			});
		})
		.catch((err) => {
			log.db.error(err);
			res.status(500).render(__path + '/src/frontend/errors/dbError.eta.html', { error: err });
		});
}

export default { get };
